Contributing to extension-helpers
===============================

The guidelines for contributing to ``extension-helpers`` are generally the same
as the [contributing guidelines for the astropy core
package](http://github.com/astropy/astropy/blob/main/CONTRIBUTING.md).
Basically, report relevant issues in the ``extension-helpers`` issue tracker, and
we welcome pull requests that broadly follow the [Astropy coding
guidelines](http://docs.astropy.org/en/latest/development/codeguide.html).
